function [detected, t_ref] = CUSUMtest (DataSet, params)
%
% function [detected, t_ref] = CUSUMtest (DataSet, params)
%
% ASSUMES SCALAR AND GAUSSIAN DISTRIBUTED DATA
%
% Politecnico di Milano
% Manuel Roveri, Giacomo Boracchi
%
% References
% [1] Michle Basseville and Igor V. Nikiforov,
%      "Detection of Abrupt Changes - Theory and Application"
%      published by Prentice-Hall, Inc. (ISBN 0-13-126780-9 - April 1993 - Englewood Cliffs, N.J.),
%
% Revision History
% 2006 First Relase by Manuel Roveri
% November 2013   modified loop, added t_ref as in
% December  2013   added uncertainity in the true paramters thea0 and theta1 and estimate theta0 from params.tsLength
%                                 initial samples in DataSet
%

if(~isfield(params, 'do_compute_t_ref') || isempty(params.do_compute_t_ref))
    do_compute_t_ref = 0;
else
    do_compute_t_ref = params.do_compute_t_ref;
end

% if(~isfield(params, 'tsLength') || isempty(params.tsLength))
%     params.tsLength = 0;
% end
% 
% if(~isfield(params, 'theta0Perturbation') || isempty(params.theta0Perturbation))
%     params.theta0Perturbation = 0;
% end
% 
% if(~isfield(params, 'theta1Perturbation') || isempty(params.theta1Perturbation))
%     params.theta1Perturbation = 0;
% end

res=0;
detected = 0;
g1=0; % cumulative sum
N=  length(DataSet);
i = 1;

%% estimate THETA0 parameters using sample estimator DISABLED AT THE MOMENT

mu0 = params.mu0;
mu1 = params.mu1;
sigma0 = params.sigma0;
sigma1 = params.sigma1;

% if params.tsLength > 0
%     mu0 = mean(DataSet(1 : params.tsLength));
%     sigma0 = std(DataSet(1 : params.tsLength));
% end
% 
% % add a Gaussian perturbation to the parameters to be used
% if  params.theta0Perturbation >0 
%     mu0 = mu0 + params.theta0Perturbation * randn(size(mu0));
%     sigma0 = sigma0 + params.theta0Perturbation * randn(size(sigma0));
% end
% 
% if  params.theta1Perturbation >0 
%     mu1 = mu1 + params.theta1Perturbation * randn(size(mu1));
%     sigma1 = sigma1 + params.theta1Perturbation * randn(size(sigma1));
% end

h = params.h;

%% CUSUM starts
while i <= N && res == 0
    currData = DataSet(i);
    
    % Compute Likelihood for stationry and alternative distribution
    Z0 = normpdf(currData, mu0, sigma0);
    Z1 = normpdf(currData, mu1, sigma1);
    
    % compute the likelihood ratio
    Zlog1=log(Z1/Z0);
    if (g1+Zlog1) > 0
        g1=g1 + Zlog1;
    else
        g1=0;
    end
    
    % compare against the threshold
    if (g1> h)
        res =1;
        detected = i;
    end
    
    i = i + 1;
end

%% compute t_ref as in [1] 2.6.9

t_ref = 0;
if do_compute_t_ref && detected > 0
    GAP = max([1, detected - params.MAXIMUM_WINDOW_T_REF]);
    p0 = normpdf(DataSet(1 : detected), mu0, sigma0);
    p1 = normpdf(DataSet(1 : detected), mu1, sigma1);

    likelihoodVals = NaN(1, detected);
    
    for ii =GAP : numel(p0)
        likelihoodVals(ii) = sum(log(p0(1 : ii))) + sum(log(p1(ii + 1 : end)));
    end
    
    [~, t_ref] = max(likelihoodVals);
 
    %     figure(213), plot([GAP: detected - GAP - 1], mle(GAP: end - GAP - 1)), hold on, plot(t_ref, mle(t_ref), 'rx'), title(['t_ref = ', num2str(t_ref)])
end