function [detected, res, et] = CUSUMtest_twoSided(data, mu0, mu1, mu2, sigma, h)
%
% function [detected, res, et] = CUSUMtest_twoSided(data, mu0, mu1, mu2, sigma, h)
%
% ASSUMES SCALAR AND GAUSSIAN DISTRIBUTED DATA
%
%
% res == 1  process changes in the direction of mu1
% res == -1 process changes in the direction of mu2
%
%
% Revision History
% 2006 First Relase by Manuel Roveri
% November 2013   modified loop 
%


init=cputime;
res=0;
detected = 0;
g1=0; % cumulative sum
N=  length(data);
i = 1;

%%  two sided CUSUM starts
while i <= N && res == 0
    currData=data(i);
    
    % Compute Likelihood for stationry and alternative distributions
    Z0=normpdf(currData, mu0, sigma);
    Z1=normpdf(currData, mu1, sigma);
    Z2=normpdf(currData, mu2, sigma);
   
    %    % compute the likelihood ratio m0 vs m1
    Zlog1=log(Z1/Z0);  
    if (g1+Zlog1)>0
        g1=g1+Zlog1;
    else
        g1=0;
    end

    %   compute the likelihood ratio  m0 vs m2
    Zlog2=log(Z2/Z0);  
    if (g2+Zlog2)>0
        g2=g2+Zlog2;
    else
        g2=0;
    end
    
    % compare against thresholds
    if (g1>h & g2<h )
        res =1;
        detected = i;
    end
    
    if (g1<h & g2>h)
        res =-1;
        detected = i;
    end
    
    i = i +1;
end

et=cputime-init;