function params = define_CUSUM_standard_parameters()
%DEFINE_NPCUSUM_STANDARD_PARAMETERS defines the standard configuration of
%the NPCUSUM change detection test presented in
% "Detection of intrusions in information systems by sequential change-point methods"
% Tartakovsky et al., Statistical Methodology 3 (2006)
%
% Input:
%       - common_parameters: parameters shared with other cdt
%
% Output:
%       - standard_NPCUSUM_parameters: standard configuration for the
%       NPCUSUM change detection test
%
% Manuel Roveri, Giacomo Boracchi
% Politecnico di Milano
% roveri@elet.polimi.it, giacomo.boracchi@polimi.it
%
% Revision History
% November 2010   first release
% November 2013   added parameters for performing change validation

%% core CDT parameters

% stationary distribtion parameters, assume Gaussian distributed data
params.mu0 = 0;
params.sigma0 = 1;

% stationary distribtion parameters, assume Gaussian distributed data
params.mu1 = 0;
params.sigma1 = 1;

params.h = 10;

%% procedural parameters
params.do_stop_first_detection = 1;
params.do_validate_changes = 1;
params.do_compute_t_ref = 1;

%% parameters defining the behavior of CUSUM test on
params.tsLength = 0; % when ~= 0 these data are used to compute sample mean and sample std
params.theta0Perturbation = 0; % std  of the Gaussian random std added as a perturbation to the true parameters
params.theta1Perturbation = 0; % std  of the Gaussian random std added as a perturbation to the true parameters

%% validation parameters

params.HT_Partition = 'TrainingSet';
% change validation parameters
params.alpha = 0.05;
params.initVsLength= 80;% this data are not usd for detection just, to have a sequence to be used for validation [it is meant for the parametric case where mu0,sigma0,mu1,sigma1, are known exactly ]
params.MAXIMUM_WINDOW_T_REF = 1000;% window over the most recent samples considered to estiamate T_ref
params.MinimumTS_Size = 10;
params.HT_Name = 'ztest'; % z-test on the sample mean of the newTrainingSet, since here the distribution in stationary conditions is known

%% cross-check
if(params.tsLength > 0 || params.theta0Perturbation ~= 0 || params.theta1Perturbation ~= 0 )
    disp('cusum not configured in its ideal conditions');
end
end
