function [params] = define_NPCUSUM_standard_parameters(TS_length)
%DEFINE_NPCUSUM_STANDARD_PARAMETERS defines the standard configuration of
%the NPCUSUM change detection test presented in
% "Detection of intrusions in information systems by sequential change-point methods"
% Tartakovsky et al., Statistical Methodology 3 (2006)
%
% Input:
%       - common_parameters: parameters shared with other cdt
%
% Output:
%       - params: standard configuration for the
%       NPCUSUM change detection test
%
% See also
% [1] Cesare Alippi, Giacomo Boracchi, Manuel Roveri,
% Hierarchical Change-Detection Tests
% IEEE Transactions on Neural Networks and Learning Systems, In Press (2016), 13 pages doi:10.1109/TNNLS.2015.2512714
%
% Manuel Roveri, Giacomo Boracchi
% Politecnico di Milano
% roveri@elet.polimi.it, giacomo.boracchi@polimi.it
%
% Revision History
% November 2010   first release
% November 2013   added parameters for performing change validation

params.w = 1;  % Positive weight for the figure of merits
params.training_set_length = TS_length; % Length of the training set

params.h = 450; % Threshold for the NP-CUSUM statistic (\kappa in [1])
params.c.current = 'fixed'; % The value of the correction factor

params.c.fixed.value = 0.1; %


% c can be computed with
%   - sliding_window
%   - fixed = fixed value
params.epsilon = 0.05; % Tuning parameters for the estimate of the unknown mean (to be used only in the 'sliding_window')
params.c.sliding_window.window_size = 100; % Size of the sliding window for the 'fixed' approach

% HCDT parameters
params.do_stop_first_detection = 1;
params.do_validate_changes = 1;

%% validation parameters
params.MINIMUM_TS_SIZE_VALIDATION = 80;% minimum size of newTS and oldTS for validation

params.HT_Partition = 'TrainingSet';
% change validation parameters
params.alpha = 0.05;
params.HT_Name = 'Mann-Whitney'; %'Mann-Whitney'
params.cpmParams = define_CPM_parameters(params.HT_Name);
end
