function [setDifference , valid, ht, name] = computeSetDifference(A , B , estParams)
%
% function [setDifference , valid, ht] = computeSetDifference(A , B , estParams)
%
% setDifference    the statistic (KS, LP)
% valid                   the HT outcome, valid == 1, null hypothesis is rejected
% ht                       the threshold
%
% Giacomo Boracchi
% Politecnico di Milano
%
% giacomo.boracchi@polimi.it
%
% Revision History
% September 2012    First Release
% February 2013       Second Release: now multiple tests are considered in parallel

N = length(A) + length(B);

%%
switch lower(estParams.testType)
    
    case{'lepage', 'lp', 'l'}
        setDifference = lepageStatistic(A , B);
        ht = computeHt(estParams, N);
        valid = (setDifference > ht);
        name = estParams.testType;
    
    case{'mood', 'md'}
        setDifference = moodStatistic(A , B);
        ht = computeHt(estParams, N);
        valid = (setDifference > ht);
        name = estParams.testType;
    
%     case{'kolmogorov-smirnov','ks', 'kolmogorovsmirnov'}
%         pVal = ksStatistic(A , B);
%         ht = computeHt(estParams, N);
%         valid = (setDifference > ht);
%         name = estParams.testType;
%        
%     case{'cramer-von-mises', 'cvm', 'cramervonmises'}
%         setDifference = cvmStatistic(A, B);
%         ht = computeHt(estParams, N);
%         valid = (setDifference > ht);
%         name = estParams.testType;
             
    case{'mann-whitney','mw','mannwhitney'}
        setDifference = mwStatistic(A, B);
        ht = computeHt(estParams, N);
        valid = (setDifference > ht);
        name = estParams.testType;
        
    case{'student', 'sd'}
        setDifference = studentStatistic(A, B);
        ht = computeHt(estParams, N);
        valid = (setDifference > ht);
        name = estParams.testType;
        
    case{'all'}
        setDifference(1) = lepageStatistic(A, B);
        ht(1) = estParams.allThresholds.LP(N);
        name{1} = 'LP';
        
        setDifference(2) = moodStatistic(A, B);
        ht(2) = estParams.allThresholds.MD(N);
        name{2} = 'MD';

        setDifference(3) = mwStatistic(A , B);
        ht(3) = estParams.allThresholds.MW(N);
        name{3} = 'MW';

        setDifference(4) = cvmStatistic(A , B);
        ht(4) = estParams.allThresholds.CVM(N);
        name{4} = 'CVM';
        
        setDifference(5) = ksStatistic(A, B);
        ht(5) = estParams.allThresholds.KS(N);
        name{5} = 'KS';
        
        setDifference(6) = studentStatistic(A , B);
        ht(6) = estParams.allThresholds.SD(N);
        name{6} = 'SD';

        for ii = 1 : estParams.N_TESTS
            valid(ii) = (setDifference(ii) > ht(ii));
        end
        
end



