function [params] = define_CPM_parameters(testType, ALPHA)
%  extract from files (that has to be in a folder in the path) the
%  threholds to be used for HT using CPM (offline analysis only)
% 
%  testTypes of CPM supported so far 'LP', 'KS'; 'MD'; ' CVM'; 'MW';'SD'
%
% Giacomo Boracchi
% Politecnico di Milano
%
% giacomo.boracchi@polimi.it
%
% Revision History
% November 2013 first release, taken from createBasicSetDiffParameters in the ensemble of CPM 

if(~exist('testType', 'var') || isempty(testType))
    testType = 'lepage';
end

if(~exist('ALPHA', 'var') || isempty(ALPHA))
    params.ALPHA = 0.05; % this is the only provided at the moment. codes in R has to be fixed by Ross
else
    params.ALPHA = ALPHA;
end


%% These have to be revised

params.PART_STEP = 1;
params.minSize = 2;

params.GAP = 2;
params.STEP = 1;

% visualization parameters

params.MRK_SZ  = 5 ;
params.LN_WDT = 2;

params.testType = testType;

% it has to be in the path
ThresholdFolder = ''; 

%% determimne tresholds fileNames
switch lower(params.testType)
    case{'lepage', 'lp'}
        thresholdFileName = [ThresholdFolder, 'Lepage_threshold_alpha', num2str(params.ALPHA), '.txt'];
        
    case{'mood','md'}
        thresholdFileName = [ThresholdFolder, 'Mood_threshold_alpha', num2str(params.ALPHA), '.txt'];
        
    case{'kolmogorov-smirnov','ks'}
        thresholdFileName = [ThresholdFolder, 'Kolmogorov-Smirnov_threshold_alpha', num2str(params.ALPHA), '.txt'];
        
    case{'cramer-von-mises','cvm'}
        thresholdFileName = [ThresholdFolder, 'Cramer-von-Mises_threshold_alpha', num2str(params.ALPHA), '.txt'];
        
    case{'mann-whitney','mw'}
        thresholdFileName = [ThresholdFolder, 'Mann-Whitney_threshold_alpha', num2str(params.ALPHA), '.txt'];
        
    case{'student','sd'}
        thresholdFileName = [ThresholdFolder, 'Student_threshold_alpha', num2str(params.ALPHA), '.txt'];
        
end

%% load thresholds if needed

if strcmpi(testType, 'all')
    params.N_TESTS = 6;
    params.allThresholds.LP = load([ThresholdFolder, 'Lepage_threshold_alpha', num2str(params.ALPHA), '.txt']);
    params.allThresholds.MD = load([ThresholdFolder, 'Mood_threshold_alpha', num2str(params.ALPHA), '.txt']);
    params.allThresholds.KS = load([ThresholdFolder, 'Kolmogorov-Smirnov_threshold_alpha', num2str(params.ALPHA), '.txt']);
    params.allThresholds.CVM = load([ThresholdFolder, 'Cramer-von-Mises_threshold_alpha', num2str(params.ALPHA), '.txt']);
    params.allThresholds.MW = load([ThresholdFolder, 'Mann-Whitney_threshold_alpha', num2str(params.ALPHA), '.txt']);
    params.allThresholds.SD = load([ThresholdFolder, 'Student_threshold_alpha', num2str(params.ALPHA), '.txt']);
else
    params.N_TESTS = 1;
    params.thresholds = load(thresholdFileName);
end


