function  [TStatistic] = moodStatistic(A , B)
% function  [TStatistic] = moodStatistic(A , B)
%
%
% Reference 
% Mood, A. (1954), On the Asymptotic Efficiency of Certain Nonparametric
% Two-Sample Tests, Annals of Mathematical Statistics, 25, 514533. [381]
%
%
% Giacomo Boracchi
% Politecnico di Milano
% giacomo.boracchi@polimi.it 
%
% Revision Notes
% February 2013   First Release
% 
 
m = length(A(:));
n = length(B(:));
N = m + n;

% row vector containing both dataset
D = [A(:); B(:)]';

% labels, the original set
% L = [zeros(1, m), ones(1, n)];
% [D_sorted, indx] = sort(D,2,'descend');
% L = L(indx);
% r = find(L == 1);

[vs, vi] = sort(D);
[x, r] = sort(vi);

% Test Statistic equation (13) in Mood, A. (1954),
W = sum((r(1 : m) - (N + 1) / 2).^2);

% Expectation eq (16) in Mood, A. (1954),
EW = m * (N^2 - 1) / 12;

% Standard deviation eq (18) in Mood, A. (1954),
sigmaW =  m * n * (N + 1) * (N - 2) * (N+2)  / 180;

%% compute the normalized test statistic
TStatistic = abs((W - EW)) / sqrt(sigmaW);

