function  [TStatistic] = mwStatistic(A , B, do_use_matlab_stats)
% function  [TStatistic] = mwStatistic(A , B, do_use_matlab_stats)
%
%
% Giacomo Boracchi
% Politecnico di Milano
% giacomo.boracchi@polimi.it 
%
% Revision Notes
% February 2013   First Release
% 

if ~exist('do_use_matlab_stats ', 'var') || isempty(do_use_matlab_stats )
    do_use_matlab_stats  = 0;
end

m = length(A(:));
n = length(B(:));
N = m + n;

% row vector containing both dataset
D = [A(:); B(:)]';
% labels, the origin
L = [ones(1, m) , zeros(1, n)];
[~, indx] = sort(D);
V = L(indx);

xx =[1 : size(D, 2)] ;

% T1: Wilcoxon / Mann-Whitney statistic
T1 = xx * V';

%% compute normalization terms
mu1 = m * (N + 1) / 2;
sigma1 =  m * n * (N + 1)  / 12;

%% compute the test statistic
TStatistic = abs(T1 - mu1) / sqrt(sigma1);

if do_use_matlab_stats
    [~,~,TSstatistic] = ranksum(A,B);
    
    if (isfield(TSstatistic, 'zval'))
        TStatistic = abs(TSstatistic.zval);
    end
end







