function [valid, maxStat, T_ref] = validateChanges_Lepage(DataToCheck, cpmParams)
%
% function [valid, maxStat, T_ref] = validateChanges_Lepage(DataToCheck, cpmParams)
%
% Performs validation of a change detected by the ICI-based CDT using the Lepage CPM
% analyzes data directly from [DataSet(oldTS_Init : oldTS_End), DataSet(newTS_Init : newTS_End)]
%
% Lepage statistic is used to assess if  [DataSet(oldTS_Init : oldTS_End), DataSet(newTS_Init : newTS_End)] contains a
% change point monitoring mean and variance of the points
%
% please cite this work as:
% [1] Cesare Alippi, Giacomo Boracchi and Manuel Roveri,
% "A Hierarchical, Nonparametric Sequential Change-Detection Test"
%  in Proceedings of IJCNN 2011, the International Joint Conference on Neural Networks,
% San Jose, California July 31 - August 5, 2011. pp 2889 - 2896, DOI: 10.1109/IJCNN.2011.6033600
%
% [2] Cesare Alippi, Giacomo Boracchi and Manuel Roveri,
% "A just-in-time adaptive classification system based on the intersection of confidence intervals rule"
%  Neural Networks, Elsevier vol. 24 (2011), pp. 791-800 (doi: 10.1016/j.neunet.2011.05.012)
%
% Reference
% [3] GJ Ross, DK Tasoulis, NM Adams
% "Nonparametric Monitoring of Data Streams for Changes in Location and Scale"
% Technometrics 53 (4), 379-389
%
% [4] GJ Ross, 
% "Parametric and Nonparametric Sequential Change Detection in R: The cpm package", 
% Journal of Statistical Software,  
%
% Thresholds for offline CPM are taken from  [4]
% 
% Giacomo Boracchi
% Politecnico di Milano
% giacomo.boracchi@polimi.it
%
% Revision History
% November 2013 -   First Release

 [valid, T_ref, ~, maxStat] = runCPM(DataToCheck, cpmParams);





